//
//  EditCommentAttachmentView.swift
//  SampleApp
//
//  Created by Nishan Niraula on 17/2/2566 BE.
//  Copyright © 2566 BE David Zhang. All rights reserved.
//

import SwiftUI

struct EditCommentAttachmentView: View {
    
    @Environment(\.presentationMode) var presentationMode
    
    @State private var attachments: [String] = []
    
    let existingAttachemnts: [String]
    // Array of current selection
    let onSelection: (([String]) -> Void)?
    
    @State private var showImageChooserScreen = false
    
    var body: some View {
        ScrollView {
            VStack(alignment: .leading) {
                
                HStack {
                    Text("Existing Attachments:")
                        .font(.system(size: 18, weight: .semibold))
                    
                    Spacer()
                    
                    Button {
                        showImageChooserScreen = true
                    } label: {
                        Image(systemName: "plus.circle.fill")
                            .resizable()
                            .scaledToFit()
                            .frame(width: 24, height: 24)
                            .padding(4)
                    }
                }
                
                Divider()
                
                ForEach(attachments, id: \.self) { item in
                    HStack {
                        Text("FileId: \(item)")
                        
                        Spacer()
                        
                        Button {
                            if let firstIndex = attachments.firstIndex(where: { data in
                                return data == item
                            }) {
                                attachments.remove(at: firstIndex)
                            }
                        } label: {
                            Image(systemName: "trash.circle.fill")
                                .resizable()
                                .scaledToFit()
                                .frame(width: 24, height: 24)
                                .padding(4)
                                .foregroundColor(.secondary)
                        }
                    }
                    .padding(.vertical, 2)
                }
                .padding(.top, 16)
                
                HStack {
                    Spacer()
                    
                    Button {
                        // Notify about uploaded files
                        onSelection?(attachments)
                        
                        // Dismiss this screen
                        presentationMode.wrappedValue.dismiss()
                    } label: {
                        Text("Update Attachments")
                    }
                    .padding(8)
                    .buttonStyle(.bordered)
                    
                    Spacer()
                }
                .padding(.top, 24)
            }
            .padding()
        }
        .sheet(isPresented: $showImageChooserScreen) {
            NavigationView {
                ImageChooserView(existingSelection: []) { newSelection in
                    attachments.append(contentsOf: newSelection)
                }
                .navigationTitle(Text("Comment Images"))
                .navigationBarTitleDisplayMode(.inline)
            }
        }
        .task {
            attachments = existingAttachemnts
        }
    }
}

struct EditCommentAttachmentView_Previews: PreviewProvider {
    static var previews: some View {
        EditCommentAttachmentView(existingAttachemnts: [], onSelection: nil)
    }
}
